/*****************************************************************************************
*
* File:		main.c
* Author:	Roman Mego
* Date:		8. April 2011
*
* Brief:	Main file for RFID reader using PIC16F628A and EM4095
*
*****************************************************************************************/

#include <htc.h>
#include "usart.h"
#include "signalization.h"
#include "em4095.h"

#define _XTAL_FREQ 4000000			// oscillator frequency

char rfid_code[17];

/*****************************************************************************************
* Interrupt vector
*****************************************************************************************/

void interrupt capture(void) {
	rfid_interrupt();				// call RFID reception
	PIR1bits.CCP1IF = 0;			// clear CCP1 Interrupt Flag bit
}


/*****************************************************************************************
* Main function
******************************************************************************************
 1. initialize monules
 2. reads code from RFID module in infinite loop
 3. after reading, send to uart
*****************************************************************************************/

void main(void) {
	char m,n;

	init_rfid();
	init_usart();
	init_signalization();			// initialization

	for (m = 5; m > 0; m--) {		// blinking LED for 5 seconds
		LED_RED;
		for (n = 5; n > 0; n--) __delay_ms(100);
		LED_OFF;
		for (n = 5; n > 0; n--) __delay_ms(100);
	}

	ei();							// enable interrupts
	rfid_on();						// turn on RFID module

	while(1) {
		LED_RED;					// set LED to red

		if (rfid_read(rfid_code)) {	// read data
			LED_GREEN;				// set LED to green

			rfid_off();				// turn RFID module off (to avoid interrupting and getting program slow)
			usart_puts(rfid_code);	// send data to uart
			for (n = 10; n > 0; n--) __delay_ms(100);	// wait for 1 second
			rfid_on();				// turn on RFID again
		}
	}
}
