/*****************************************************************************************
*
* File:		usart.c
* Author:	Roman Mego
* Date:		8. April 2011
*
* Brief:	Functions for sending over USART on PIC16
*
*****************************************************************************************/

#include <htc.h>
#include "usart.h"

/*****************************************************************************************
* Initialization of USART module (only transmit)
*****************************************************************************************/

void init_usart(void) {
	RCSTAbits.SPEN = 1;			// Serial Port Enable bit
	TXSTAbits.SYNC = 0;			// Asynchronous mode

	TXSTAbits.BRGH = 1;
	SPBRG = 25;					// 9600 baud

	TXSTAbits.TXEN = 1;			// Transmit enabled
}


/*****************************************************************************************
* Send byte
*****************************************************************************************/

void usart_putc(char c) {
	while(TXSTAbits.TRMT == 0);	// wait for end of previous transmit
	TXREG = c;					// send byte
}


/*****************************************************************************************
* Send string from RAM
*****************************************************************************************/

void usart_puts(char *s) {
	while(*s) {					// sending to end of array (0x00)
		usart_putc(*(s++));		// send byte
	}
}


/*****************************************************************************************
* Send string from ROM
*****************************************************************************************/

void usart_puts_rom(const char *s) {
	while(*s) {					// sending to end of array (0x00)
		usart_putc(*(s++));		// send byte
	}
}